@@ -16,8 +16,8 @@ from testflows._core.test import Module, Suite, Test, Step, NullStep
 from testflows._core.test import TestStep, TestCase, TestSuite, TestModule, TestBackground, TestOutline
 from testflows._core.test import Context
 from testflows._core.test import Feature, Background, Scenario, Example, Outline
-from testflows._core.test import Given, When, Then, And, But, By, Finally
-from testflows._core.test import TestFeature, TestScenario, loads, ordered
+from testflows._core.test import Check, Given, When, Then, And, But, By, Finally
+from testflows._core.test import TestFeature, TestScenario, TestCheck, loads, ordered
 from testflows._core.flags import Flags
 from testflows._core.objects import OK, XOK, Fail, XFail, Skip, Error, XError, Null, XNull
 from testflows._core.objects import Name, Description, Uid, Tags, Args
